run

Function run 

pub fn run<I>(interpreter: I) -> !
where I: Interpreter + Send + 'static,
Starts the interpreter, blocking the current thread and running until killed. Windowing, graphics, sound, and timing are all handled within this method.